# xaudio

![Read the Docs](https://img.shields.io/readthedocs/xaudio)
![PyPI - Version](https://img.shields.io/pypi/v/xaudio)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](LICENSE)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/xaudio)
[![Unit-tests](https://github.com/int2code/xaudio/actions/workflows/unit_tests.yml/badge.svg?branch=main)](https://github.com/int2code/xaudio/actions/workflows/unit_tests.yml)
[![Publish Python Package](https://github.com/int2code/xaudio/actions/workflows/publish_to_pypi.yml/badge.svg)](https://github.com/int2code/xaudio/actions/workflows/publish_to_pypi.yml)

This package provides classes used to communicate with `XAudio` device over different, 
supported mediums and protocols.